% Auto-generated chapter 29 for tirmidhi
% Hadiths in this chapter: 26

\hadithdefcmd{tirmidhi}{2090}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، قال حَدَّثَنَا أَبِي، قال حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، قال حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ مَالاً فَلأَهْلِهِ وَمَنْ تَرَكَ ضَيَاعًا فَإِلَىَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَنَسٍ ‏.‏ وَقَدْ رَوَاهُ الزُّهْرِيُّ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَطْوَلَ مِنْ هَذَا وَأَتَمَّ ‏.‏ مَعْنَى ضَيَاعًا ضَائِعًا لَيْسَ لَهُ شَيْءٌ فَأَنَا أَعُولُهُ وَأُنْفِقُ عَلَيْهِ ‏.‏\hadithno{2090}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(S.A.W) said:"Whoever leaves wealth then it is for his heirs, and whoever leaves poor dependents then it (the responsibility) is for me}}
\hadithdefcmd{tirmidhi}{2091}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلٍ، قال حَدَّثَنَا مُحَمَّدُ بْنُ الْقَاسِمِ الأَسَدِيُّ، قال حَدَّثَنَا الْفَضْلُ بْنُ دَلْهَمٍ، قال حَدَّثَنَا عَوْفٌ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعَلَّمُوا الْقُرْآنَ وَالْفَرَائِضَ وَعَلِّمُوا النَّاسَ فَإِنِّي مَقْبُوضٌ ‏".‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ فِيهِ اضْطِرَابٌ وَرَوَى أَبُو أُسَامَةَ، هَذَا الْحَدِيثَ عَنْ عَوْفٍ، عَنْ رَجُلٍ، عَنْ سُلَيْمَانَ بْنِ جَابِرٍ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ الْحُسَيْنُ بْنُ حُرَيْثٍ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، بِهَذَا بِمَعْنَاهُ ‏.‏ وَمُحَمَّدُ بْنُ الْقَاسِمِ الأَسَدِيُّ قَدْ ضَعَّفَهُ أَحْمَدُ بْنُ حَنْبَلٍ وَغَيْرُهُ ‏.‏\hadithno{2091}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(S.A.W) said:"Learn the laws of inheritance and the Quran, and teach the people, for I am a mortal}}
\hadithdefcmd{tirmidhi}{2092}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قال حَدَّثَنِي زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَتِ امْرَأَةُ سَعْدِ بْنِ الرَّبِيعِ بِابْنَتَيْهَا مِنْ سَعْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ هَاتَانِ ابْنَتَا سَعْدِ بْنِ الرَّبِيعِ قُتِلَ أَبُوهُمَا مَعَكَ يَوْمَ أُحُدٍ شَهِيدًا وَإِنَّ عَمَّهُمَا أَخَذَ مَالَهُمَا فَلَمْ يَدَعْ لَهُمَا مَالاً وَلاَ تُنْكَحَانِ إِلاَّ وَلَهُمَا مَالٌ ‏.‏ قَالَ ‏"‏ يَقْضِي اللَّهُ فِي ذَلِكَ ‏"‏ ‏.‏ فَنَزَلَتْ آيَةُ الْمِيرَاثِ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَمِّهِمَا فَقَالَ ‏"‏ أَعْطِ ابْنَتَىْ سَعْدٍ الثُّلُثَيْنِ وَأَعْطِ أُمَّهُمَا الثُّمُنَ وَمَا بَقِيَ فَهُوَ لَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ وَقَدْ رَوَاهُ شَرِيكٌ أَيْضًا عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ ‏.‏\hadithno{2092}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin 'Abdullah said:"The wife of Sa'd bin Ar-Rabi came with her two daughters from Sa'd to he Messenger of Allah(S.A.W)and said; O Messenger of Allah(S.A.W)! these two are daughters of Sa'd bin Ar-Rabi who fought along with you on the day of Uhud and was martyred. Their uncle took their wealth, without leaving any wealth for them, and they will not be married unless they have wealth.' He said: 'Allah will decide on that matter.' The ayah about inheritance was revealed, so the Messenger of Allah(S.A.W) sent (word) to their Uncle saying: Give the two daughters of Sa'd two thirds, and give their mother one eighth, and whatever remains, then it is for you}}
\hadithdefcmd{tirmidhi}{2093}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ, قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، قَالَ جَاءَ رَجُلٌ إِلَى أَبِي مُوسَى وَسَلْمَانَ بْنِ رَبِيعَةَ فَسَأَلَهُمَا عَنْ الاِبْنَةِ، وَابْنَةِ الاِبْنِ، وَأُخْتٍ، لأَبٍ وَأُمٍّ فَقَالاَ لِلاِبْنَةِ النِّصْفُ وَلِلأُخْتِ مِنَ الأَبِ وَالأُمِّ مَا بَقِيَ ‏.‏ وَقَالاَ لَهُ انْطَلِقْ إِلَى عَبْدِ اللَّهِ فَاسْأَلْهُ فَإِنَّهُ سَيُتَابِعُنَا ‏.‏ فَأَتَى عَبْدَ اللَّهِ فَذَكَرَ ذَلِكَ لَهُ وَأَخْبَرَهُ بِمَا قَالاَ قَالَ عَبْدُ اللَّهِ قَدْ ضَلَلْتُ إِذًا وَمَا أَنَا مِنَ الْمُهْتَدِينَ وَلَكِنْ أَقْضِي فِيهِمَا كَمَا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم لِلاِبْنَةِ النِّصْفُ وَلاِبْنَةِ الاِبْنِ السُّدُسُ تَكْمِلَةَ الثُّلُثَيْنِ وَلِلأُخْتِ مَا بَقِيَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَبُو قَيْسٍ الأَوْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ ثَرْوَانَ الْكُوفِيُّ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ أَبِي قَيْسٍ ‏.‏\hadithno{2093}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Huzail bin Shurahbil said:"A man came to Abu Musa and Salman bin Rabiah and asked them about a daughter, a son's daughter, a father's sister and a mother's sister. So they said: 'For the daughter is half, for the sister of the father and the mother is what remains.' And they said to him: Go to Abdullah (bin Masud) and ask him, for surely he will concur with us.' So he went to 'Abdullah mentioning that to him and informing him what they had said. 'Abdulah said: 'If that were the case, then I would ave erred and not been among the rightly-guided (on the matter). Rather, I will judge with what the Messenger of Allah(S.A.W) judged: For the daughter is half, for the son's daughter a sixth, totaling two-thirds and for the sister is what remains}}
\hadithdefcmd{tirmidhi}{2094}{حَدَّثَنَا بُنْدَارٌ، قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، أَنَّهُ قَالَ إِنَّكُمْ تَقْرَءُونَ هَذِهِ الآيَةَ ‏:‏ ‏(‏مِنْ بَعْدِ وَصِيَّةٍ تُوصُونَ بِهَا أَوْ دَيْنٍ ‏)‏ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالدَّيْنِ قَبْلَ الْوَصِيَّةِ وَإِنَّ أَعْيَانَ بَنِي الأُمِّ يَتَوَارَثُونَ دُونَ بَنِي الْعَلاَّتِ الرَّجُلُ يَرِثُ أَخَاهُ لأَبِيهِ وَأُمِّهِ دُونَ أَخِيهِ لأَبِيهِ ‏.‏ حَدَّثَنَا بُنْدَارٌ، قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2094}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Harith narrated that 'Ali said:"You recite this ayah: After payment of legacies he(or she) may have bequeathed or debts, without causing harm. And indeed the Messenger of Allah(S.A.W) judged the debt before the will and that the children (sons and daughters)from the same mother and father inherit,not the sons from various mothers. The man inherits from his brother from his father, and his mother, not his brother from his father. Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2095}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قال حَدَّثَنَا سُفْيَانُ، قال حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ أَعْيَانَ بَنِي الأُمِّ يَتَوَارَثُونَ دُونَ بَنِي الْعَلاَّتِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي الْحَارِثِ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ ‏.‏\hadithno{2095}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Harith narrated that 'Ali said:"The Messenger of Allah(S.A.W) judged that the children (sons and daughters) from the same mother and father inherit, not the sons from various mothers}}
\hadithdefcmd{tirmidhi}{2096}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قال حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدٍ، أَخْبَرَنَا عَمْرُو بْنُ أَبِي قَيْسٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي وَأَنَا مَرِيضٌ فِي بَنِي سَلِمَةَ فَقُلْتُ يَا نَبِيَّ اللَّهِ كَيْفَ أَقْسِمُ مَالِي بَيْنَ وَلَدِي فَلَمْ يَرُدَّ عَلَىَّ شَيْئًا فَنَزَلَتْ ‏:‏ ‏(‏يُوصِيكُمُ اللَّهُ فِي أَوْلاَدِكُمْ لِلذَّكَرِ مِثْلُ حَظِّ الأُنْثَيَيْنِ ‏)‏ الآيَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَابْنُ عُيَيْنَةَ وَغَيْرُهُ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ جَابِرٍ.‏\hadithno{2096}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin 'Abdullah said:"The Messenger of Allah(S.A.W) came to visit me while I was ill at Banu Salamah. I said : 'O Prophet of Allah(S.A.W)! How shall I divide my wealth among my children?' But he did not say anything to me, until the following was revealed: Allah commands you regarding your children's (inheritance): to the male, a portion equal to that of two females}}
\hadithdefcmd{tirmidhi}{2097}{حَدَّثَنَا الْفَضْلُ بْنُ الصَّبَّاحِ الْبَغْدَادِيُّ، قال أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قال أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَرِضْتُ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي فَوَجَدَنِي قَدْ أُغْمِيَ عَلَىَّ فَأَتَى وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَهُمَا مَاشِيَانِ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَبَّ عَلَىَّ مِنْ وَضُوئِهِ فَأَفَقْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَقْضِي فِي مَالِي أَوْ كَيْفَ أَصْنَعُ فِي مَالِي فَلَمْ يُجِبْنِي شَيْئًا وَكَانَ لَهُ تِسْعُ أَخَوَاتٍ حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ ‏:‏ ‏(‏يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ ‏)‏ الآيَةَ ‏.‏ قَالَ جَابِرٌ فِيَّ نَزَلَتْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2097}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jabir bin 'Abdullah said:"I was ill, so the Messenger of Allah(S.A.W)came to visit me and found me unconscious. He came walking while Abu Bakr and 'Umar were with him. The Messenger of Allah(S.A.W) performed Wudu, then poured the remaining water on me, so I came to my senses. I said: 'O Messenger of Allah(S.A.W)! how shall I dispose of my wealth?' - or - 'What shall I do with my wealth?' He did not reply anything to me" -and he had nine sisters- "until the Ayah about the inheritance was revealed: they ask you for a legal verdict. Say: "Allah directs (thus) about Al-Kalalah." Jabir said: "It was revealed regarding me}}
\hadithdefcmd{tirmidhi}{2098}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلْحِقُوا الْفَرَائِضَ بِأَهْلِهَا فَمَا بَقِيَ فَهُوَ لأَوْلَى رَجُلٍ ذَكَرٍ ‏"‏ ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رَوَى بَعْضُهُمْ عَنِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{2098}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah(S.A.W) said:"Give the shares of inheritance to those who are entitled to them. As for what remains, then it is for the closet male relative." Another chain reports similar narration}}
\hadithdefcmd{tirmidhi}{2099}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هَمَّامِ بْنِ يَحْيَى، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ ابْنِي مَاتَ فَمَا لِي فِي مِيرَاثِهِ قَالَ ‏"‏ لَكَ السُّدُسُ ‏"‏ ‏.‏ فَلَمَّا وَلَّى دَعَاهُ فَقَالَ ‏"‏ لَكَ سُدُسٌ آخَرُ ‏"‏ ‏.‏ فَلَمَّا وَلَّى دَعَاهُ قَالَ ‏"‏ إِنَّ السُّدُسَ الآخَرَ طُعْمَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ مَعْقِلِ بْنِ يَسَارٍ ‏.‏\hadithno{2099}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Imran bin Husain narrated:"A man came to the Prophet (S.A.W) and said" 'My son died, so what do I inherit from him?' He said: 'For you is a sixth.' When he turned to leave,he called him and said: 'For you is another sixth.' So when he turned to leave , he called him saying: 'The last sixth is consumable for you}}
\hadithdefcmd{tirmidhi}{2100}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قال حَدَّثَنَا سُفْيَانُ، قال حَدَّثَنَا الزُّهْرِيُّ، قَالَ مَرَّةً قَالَ قَبِيصَةُ وَقَالَ مَرَّةً رَجُلٌ عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ قَالَ جَاءَتِ الْجَدَّةُ أُمُّ الأُمِّ أَوْ أُمُّ الأَبِ إِلَى أَبِي بَكْرٍ فَقَالَتْ إِنَّ ابْنَ ابْنِي أَوِ ابْنَ بِنْتِي مَاتَ وَقَدْ أُخْبِرْتُ أَنَّ لِي فِي كِتَابِ اللَّهِ حَقًّا ‏.‏ فَقَالَ أَبُو بَكْرٍ مَا أَجِدُ لَكِ فِي الْكِتَابِ مِنْ حَقٍّ وَمَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى لَكِ بِشَيْءٍ وَسَأَسْأَلُ النَّاسَ ‏.‏ قَالَ فَسَأَلَ فَشَهِدَ الْمُغِيرَةُ بْنُ شُعْبَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهَا السُّدُسَ ‏.‏ قَالَ وَمَنْ سَمِعَ ذَلِكَ مَعَكَ قَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ ‏.‏ قَالَ فَأَعْطَاهَا السُّدُسَ ثُمَّ جَاءَتِ الْجَدَّةُ الأُخْرَى الَّتِي تُخَالِفُهَا إِلَى عُمَرَ ‏.‏ قَالَ سُفْيَانُ وَزَادَنِي فِيهِ مَعْمَرٌ عَنِ الزُّهْرِيِّ وَلَمْ أَحْفَظْهُ عَنِ الزُّهْرِيِّ وَلَكِنْ حَفِظْتُهُ مِنْ مَعْمَرٍ أَنَّ عُمَرَ قَالَ إِنِ اجْتَمَعْتُمَا فَهُوَ لَكُمَا وَأَيَّتُكُمَا انْفَرَدَتْ بِهِ فَهُوَ لَهَا ‏.‏\hadithno{2100}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Qabisah bin Dhuw'aib said:"A grandmother - the mother of a mother, or the mother of a father - came to Abu Bakr and she said: 'a son of my son' - or, 'a son of my daughter died, and I have been informed that there is a right ( from the wealth) for me in the Book.' So Abu Bakr said: 'I do not find that there is a right for you in the Book, and I have not heard that the Messenger of Allah(S.A.W) judged anything for you. I shall ask the people.' So, Al-Mughirah bin Shu'bah testified that the Messenger of Allah(S.A.W) gave her (case) a sixth. He said: 'And who heard that along with you?' He said: 'Muhammad bin Maslamah.'" He said: "So he gave her a sixth. Then the other grandmother who was left behind came to 'Umar." Sufyan said: "And Ma'mar said to me in addition, from Az-Zuhri - and I do not remember it to be from Az-Zuhri, rather I remember it to be from Ma'mar - that 'Umar said: 'If the two of you are together then it is for both of you, and whichever of you is alone with it (the sixth), then it is for her}}
\hadithdefcmd{tirmidhi}{2101}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، قال حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُثْمَانَ بْنِ إِسْحَاقَ بْنِ خَرَشَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، قَالَ جَاءَتِ الْجَدَّةُ إِلَى أَبِي بَكْرٍ تَسْأَلُهُ مِيرَاثَهَا ‏.‏ قَالَ فَقَالَ لَهَا مَا لَكِ فِي كِتَابِ اللَّهِ شَيْءٌ وَمَا لَكِ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم شَيْءٌ فَارْجِعِي حَتَّى أَسْأَلَ النَّاسَ ‏.‏ فَسَأَلَ النَّاسَ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهَا السُّدُسَ ‏.‏ فَقَالَ أَبُو بَكْرٍ هَلْ مَعَكَ غَيْرُكَ فَقَامَ مُحَمَّدُ بْنُ مَسْلَمَةَ الأَنْصَارِيُّ فَقَالَ مِثْلَ مَا قَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ فَأَنْفَذَهُ لَهَا أَبُو بَكْرٍ ‏.‏ قَالَ ثُمَّ جَاءَتِ الْجَدَّةُ الأُخْرَى إِلَى عُمَرَ بْنِ الْخَطَّابِ تَسْأَلُهُ مِيرَاثَهَا فَقَالَ مَا لَكِ فِي كِتَابِ اللَّهِ شَيْءٌ وَلَكِنْ هُوَ ذَاكَ السُّدُسُ فَإِنِ اجْتَمَعْتُمَا فِيهِ فَهُوَ بَيْنَكُمَا وَأَيَّتُكُمَا خَلَتْ بِهِ فَهُوَ لَهَا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ بُرَيْدَةَ ‏.‏ وَهَذَا أَحْسَنُ وَهُوَ أَصَحُّ مِنْ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{2101}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qabisah bin Dhuw'aib said:"A grandmother came to Abu Bakr to ask him about her inheritance. He said to her, 'There is noting for you in the Book of Allah and there is nothing for you in the Sunnah of the Messenger of Allah(S.A.W). So ,return until I ask the people. So he asked the people and Al-Mughirah bin Shu'bah said: 'I was present when the Messenger of Allah(S.A.W) gave her (case) a sixth.' So he said: 'Was anyone else with you?' Muhammad bin Maslamah stood to say the same as what Al-Mughirah bin Shu'bah said. So Abu Bakr implemented that for her." Then the other grandmother came to 'Umar bin Al-Khattab to ask him about her inheritance. He said: 'There is nothing in the Book of Allah for you, but there is that sixth. So if the two of you are together then it is for both of you, and whichever of you remains), then it is for her}}
\hadithdefcmd{tirmidhi}{2102}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، قال حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ سَالِمٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ فِي الْجَدَّةِ مَعَ ابْنِهَا إِنَّهَا أَوَّلُ جَدَّةٍ أَطْعَمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم سُدُسًا مَعَ ابْنِهَا وَابْنُهَا حَىٌّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ - وَقَدْ وَرَّثَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم الْجَدَّةَ مَعَ ابْنِهَا وَلَمْ يُوَرِّثْهَا بَعْضُهُمْ ‏.‏\hadithno{2102}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Mas'ud said, about the grandmother along with her daughter:"The Messenger of Allah(S.A.W) gave the first grandmother, along with her son, a sixth for them to consume while her son was living}}
\hadithdefcmd{tirmidhi}{2103}{حَدَّثَنَا بُنْدَارٌ، قال: حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قال: حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حَكِيمِ بْنِ عَبَّادِ بْنِ حُنَيْفٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ كَتَبَ عُمَرُ بْنُ الْخَطَّابِ إِلَى أَبِي عُبَيْدَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُ وَرَسُولُهُ مَوْلَى مَنْ لاَ مَوْلَى لَهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَائِشَةَ وَالْمِقْدَامِ بْنِ مَعْدِيكَرِبَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2103}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah bin Sahl bin Hunaif said:"'Umar bin Al-Khattab sent me with a letter to Abu'Ubaidah (saying) that The Messenger of Allah(S.A.W) said : 'Allah and His Messenger are responsible for the one who has no patron. And the maternal uncle inherits from the one who has no heirs}}
\hadithdefcmd{tirmidhi}{2104}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قال: أَخْبَرَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَقَدْ أَرْسَلَهُ بَعْضُهُمْ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ ‏.‏ - وَاخْتَلَفَ فِيهِ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فَوَرَّثَ بَعْضُهُمُ الْخَالَ وَالْخَالَةَ وَالْعَمَّةَ وَإِلَى هَذَا الْحَدِيثِ ذَهَبَ أَكْثَرُ أَهْلِ الْعِلْمِ فِي تَوْرِيثِ ذَوِي الأَرْحَامِ وَأَمَّا زَيْدُ بْنُ ثَابِتٍ فَلَمْ يُوَرِّثْهُمْ وَجَعَلَ الْمِيرَاثَ فِي بَيْتِ الْمَالِ ‏.‏\hadithno{2104}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated that the Messenger of Allah(S.A.W) said:"The maternal uncle inherits from the one who has no heirs}}
\hadithdefcmd{tirmidhi}{2105}{حَدَّثَنَا بُنْدَارٌ، قال: حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قال: أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ مُجَاهِدٍ، وَهُوَ ابْنُ وَرْدَانَ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ مَوْلًى، لِلنَّبِيِّ صلى الله عليه وسلم وَقَعَ مِنْ عِذْقِ نَخْلَةٍ فَمَاتَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ انْظُرُوا هَلْ لَهُ مِنْ وَارِثٍ ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَادْفَعُوهُ إِلَى بَعْضِ أَهْلِ الْقَرْيَةِ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2105}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Aishah narrated that a freed slave of the Prophet (s.a.w) fell from foliage on a date-palm and died. So the Prophet (S.A.W) said:"See if he has any heirs." They said: "No." He said: 'Pay it to someone among the people of the town}}
\hadithdefcmd{tirmidhi}{2106}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، قال: حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَوْسَجَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، مَاتَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَدَعْ وَارِثًا إِلاَّ عَبْدًا هُوَ أَعْتَقَهُ فَأَعْطَاهُ النَّبِيُّ صلى الله عليه وسلم مِيرَاثَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ فِي هَذَا الْبَابِ إِذَا مَاتَ الرَّجُلُ وَلَمْ يَتْرُكْ عَصَبَةً أَنَّ مِيرَاثَهُ يُجْعَلُ فِي بَيْتِ مَالِ الْمُسْلِمِينَ ‏.‏\hadithno{2106}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn 'Abbas narrated that :a man died during the time of the Messenger of Allah(S.A.W) ,and he did not leave any heirs except for a slave that he had freed. So the Prophet gave him his inheritance}}
\hadithdefcmd{tirmidhi}{2107}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا هُشَيْمٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ وَلاَ الْكَافِرُ الْمُسْلِمَ ‏"‏ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ حَدَّثَنَا الزُّهْرِيُّ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ جَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ هَكَذَا رَوَاهُ مَعْمَرٌ وَغَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ نَحْوَ هَذَا ‏.‏ وَرَوَى مَالِكٌ عَنِ الزُّهْرِيِّ عَنْ عَلِيِّ بْنِ حُسَيْنٍ عَنْ عُمَرَ بْنِ عُثْمَانَ عَنْ أُسَامَةَ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَحَدِيثُ مَالِكٍ وَهَمٌ وَهِمَ فِيهِ مَالِكٌ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ مَالِكٍ فَقَالَ عَنْ عَمْرِو بْنِ عُثْمَانَ وَأَكْثَرُ أَصْحَابِ مَالِكٍ قَالُوا عَنْ مَالِكٍ عَنْ عُمَرَ بْنِ عُثْمَانَ وَعَمْرُو بْنُ عُثْمَانَ بْنِ عَفَّانَ هُوَ مَشْهُورٌ مِنْ وَلَدِ عُثْمَانَ وَلاَ يُعْرَفُ عُمَرُ بْنُ عُثْمَانَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ وَاخْتَلَفَ بَعْضُ أَهْلِ الْعِلْمِ فِي مِيرَاثِ الْمُرْتَدِّ فَجَعَلَ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصَحْابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْمَالَ لِوَرَثَتِهِ مِنَ الْمُسْلِمِينَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يَرِثُهُ وَرَثَتُهُ مِنَ الْمُسْلِمِينَ وَاحْتَجُّوا بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ ‏"‏ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{2107}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Usamah bin Zaid narrated that the Messenger of Allah(S.A.W) said:"The Muslim does not inherit from the disbeliever, nor the disbeliever from the Muslim." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2108}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قال: حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَوَارَثُ أَهْلُ مِلَّتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ جَابِرٍ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي لَيْلَى ‏.‏\hadithno{2108}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated that the Prophet(S.A.W) said:"The people of two religions do not inherit from each other}}
\hadithdefcmd{tirmidhi}{2109}{حَدَّثَنَا قُتَيْبَةُ، قال: حَدَّثَنَا اللَّيْثُ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْقَاتِلُ لاَ يَرِثُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ يَصِحُّ وَلاَ يُعْرَفُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ قَدْ تَرَكَهُ بَعْضُ أَهْلِ الْحَدِيثِ مِنْهُمْ أَحْمَدُ بْنُ حَنْبَلٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْقَاتِلَ لاَ يَرِثُ كَانَ الْقَتْلُ عَمْدًا أَوْ خَطَأً ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا كَانَ الْقَتْلُ خَطَأً فَإِنَّهُ يَرِثُ وَهُوَ قَوْلُ مَالِكٍ ‏.‏\hadithno{2109}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Prophet(S.A.W) said:"The murderer will not inherit}}
\hadithdefcmd{tirmidhi}{2110}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ عُمَرُ الدِّيَةُ عَلَى الْعَاقِلَةِ وَلاَ تَرِثُ الْمَرْأَةُ مِنْ دِيَةِ زَوْجِهَا شَيْئًا ‏.‏ فَأَخْبَرَهُ الضَّحَّاكُ بْنُ سُفْيَانَ الْكِلاَبِيُّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَيْهِ أَنْ وَرِّثِ امْرَأَةَ أَشْيَمَ الضِّبَابِيِّ مِنْ دِيَةِ زَوْجِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2110}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'eed bin Al-Musayyab said:"'Umar said: 'The blood-money is upon the 'Aqilah, and the wife does not inherit anything from the blood-money of her husband.' So Ad-Dahhak bin Sufyan Al-Kilabi informed him that the Messenger of Allah(S.A.W) wrote to him, (saying) to give the wife of Ashyam Ad-Dababi the inheritance from her husband's blood-money}}
\hadithdefcmd{tirmidhi}{2111}{حَدَّثَنَا قُتَيْبَةُ، قال حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي جَنِينِ امْرَأَةٍ مِنْ بَنِي لَحْيَانَ سَقَطَ مَيِّتًا بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ثُمَّ إِنَّ الْمَرْأَةَ الَّتِي قُضِيَ عَلَيْهَا بِالْغُرَّةِ تُوُفِّيَتْ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ مِيرَاثَهَا لِبَنِيهَا وَزَوْجِهَا وَأَنَّ عَقْلَهَا عَلَى عَصَبَتِهَا ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى يُونُسُ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَرَوَاهُ مَالِكٌ عَنِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ وَمَالِكٌ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ ‏.‏\hadithno{2111}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah(S.A.W) judged the payment of a Gurrah male or female slave in the case of a woman's fetus from Banu Libyan which miscarried. Then the woman who was required to give the Gurrah died, so the Messenger of Allah(S.A.W) judged that her inheritance be given to her children and her husband, and that her blood-money be paid by her 'Asabah}}
\hadithdefcmd{tirmidhi}{2112}{حَدَّثَنَا أَبُو كُرَيْبٍ، قال: حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ وَوَكِيعٌ عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، وَقَالَ، بَعْضُهُمْ عَنْ عَبْدِ اللَّهِ بْنِ وَهْبٍ، عَنْ تَمِيمٍ الدَّارِيِّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا السُّنَّةُ فِي الرَّجُلِ مِنْ أَهْلِ الشِّرْكِ يُسْلِمُ عَلَى يَدَىْ رَجُلٍ مِنَ الْمُسْلِمِينَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ أَوْلَى النَّاسِ بِمَحْيَاهُ وَمَمَاتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ وَهْبٍ وَيُقَالُ ابْنُ مَوْهَبٍ عَنْ تَمِيمٍ الدَّارِيِّ ‏.‏ وَقَدْ أَدْخَلَ بَعْضُهُمْ بَيْنَ عَبْدِ اللَّهِ بْنِ وَهْبٍ وَبَيْنَ تَمِيمٍ الدَّارِيِّ قَبِيصَةَ بْنَ ذُؤَيْبٍ وَلاَ يَصِحُّ رَوَاهُ يَحْيَى بْنُ حَمْزَةَ عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ وَزَادَ فِيهِ قَبِيصَةَ بْنَ ذُؤَيْبٍ وَهُوَ عِنْدِي لَيْسَ بِمُتَّصِلٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَقَالَ بَعْضُهُمْ يُجْعَلُ مِيرَاثُهُ فِي بَيْتِ الْمَالِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَاحْتَجَّ بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{2112}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abudullah bin Mawhab - and some of them said- 'Abdullah bin Wahb, narrated from Tamim Ad-Dari who said:'I asked the Messenger of Allah(S.A.W): What is the Sunnah regarding a man among the people of the Shirk who accepts Islam at the hand of a man among the Muslims?' So the Messenger of Allah(S.A.W) said: "He is the closet of the people to him in his life and in his death}}
\hadithdefcmd{tirmidhi}{2113}{حَدَّثَنَا قُتَيْبَةُ، قال حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ عَاهَرَ بِحُرَّةٍ أَوْ أَمَةٍ فَالْوَلَدُ وَلَدُ زِنَا لاَ يَرِثُ وَلاَ يُورَثُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى غَيْرُ ابْنِ لَهِيعَةَ هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ شُعَيْبٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ وَلَدَ الزِّنَا لاَ يَرِثُ مِنْ أَبِيهِ.‏\hadithno{2113}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that the Messenger of Allah(S.A.W) said:"Any man who fornicates with a free woman, or a slave woman, then the child born from Zina does not inherit, nor is it inherited from}}
\hadithdefcmd{tirmidhi}{2114}{حَدَّثَنَا قُتَيْبَةُ، قال: حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَرِثُ الْوَلاَءَ مَنْ يَرِثُ الْمَالَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{2114}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu'aib narrated from his father, from his grandfather, that the Messenger of Allah(S.A.W) said:"The one who inherits the Wala is the one who inherits the wealth}}
\hadithdefcmd{tirmidhi}{2115}{حَدَّثَنَا هَارُونُ أَبُو مُوسَى الْمُسْتَمْلِيُّ الْبَغْدَادِيُّ، قال: حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، قال: حَدَّثَنَا عُمَرُ بْنُ رُؤْبَةَ التَّغْلِبِيُّ، عَنْ عَبْدِ الْوَاحِدِ بْنِ عَبْدِ اللَّهِ أَبِي بُسْرٍ النَّصْرِيِّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَرْأَةُ تَحُوزُ ثَلاَثَةَ مَوَارِيثَ عَتِيقَهَا وَلَقِيطَهَا وَوَلَدَهَا الَّذِي لاَعَنَتْ عَلَيْهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ يُعْرَفُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ مُحَمَّدِ بْنِ حَرْبٍ ‏.‏\hadithno{2115}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Wathilah bin Al-Asqa' narrated that the Messenger of Allah(S.A.W) said:"The woman collects three inheritance: Whomever she freed, whomever she found, and the child for which she made Li'an}}
